# TorrentFileQt

## Version 0.2.0

### Fixed

    - Bug Fixes
    - lots of bug fixes
    - upgraded support to newest torrentfile version 0.5.0

### Added

    - pre-compiled executables for window.
    - Check Tab for re-checking torrent download completion
    - docstrings
    - screenshots for reame

----------

## Version 0.1.0

### Added

    - GUI front end to TorrentFile CLI
    - Unit testing framework
    - Initial code commits
    - PySide6 widgets
